AnimatedSnackBar class

Constructors

AnimatedSnackBar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

style1({required BuildContext context, String? label, Color? primaryColor, required SnackBarType snackBarType, TextStyle? labelTextStyle, double? iconAvatarRadius, Color? iconColor, Duration? duration, DismissDirection? direction, bool? hasLabel}) → dynamic